use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007000
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
irc
Florian
Ragwitz
rafl
Peter
Rabbitson
ribasushi
Karen
Etheridge
ether
Christian
Walde
walde
Simon
Wilper
sxw
Tatsuhiko
Miyagawa
miyagawa
Tomas
Doran
bobtfish
lib
Hooks
EndOfScope
PP
FieldHash
HintHash
XS
